@@ -13,7 +13,7 @@ import six
 from six.moves.urllib.parse import urlencode
 from nylas._client_sdk_version import __VERSION__
 from nylas.client.delta_collection import DeltaCollection
-from nylas.client.errors import MessageRejectedError, NylasApiError
+from nylas.client.errors import MessageRejectedError, NylasApiError, RateLimitError
 from nylas.client.outbox_models import Outbox
 from nylas.client.restful_model_collection import RestfulModelCollection
 from nylas.client.restful_models import (
@@ -33,6 +33,7 @@ from nylas.client.restful_models import (
     Component,
     JobStatus,
     Webhook,
+    Send,
 )
 from nylas.client.neural_api_models import Neural
 from nylas.client.scheduler_restful_model_collection import (
@@ -66,12 +67,21 @@ def _validate(response):
         # we will handle it separate and handle a _different_ exception
         # so that users don't think they need to pay.
         raise MessageRejectedError(response)
+    elif response.status_code == 429:
+        raise RateLimitError(response)
     elif response.status_code >= 400:
         raise NylasApiError(response)
 
     return response
 
 
+def _validate_availability_query(query):
+    if (query.get("emails", None) is None or len(query["emails"]) == 0) and (
+        query.get("calendars", None) is None or len(query["calendars"]) == 0
+    ):
+        raise ValueError("Must set either 'emails' or 'calendars' in the query.")
+
+
 class APIClient(json.JSONEncoder):
     """API client for the Nylas API."""
 
@@ -145,6 +155,8 @@ class APIClient(json.JSONEncoder):
         login_hint="",
         state="",
         scopes=("email", "calendar", "contacts"),
+        provider="",
+        redirect_on_error=None,
     ):
         args = {
             "redirect_uri": redirect_uri,
@@ -158,6 +170,16 @@ class APIClient(json.JSONEncoder):
             if isinstance(scopes, str):
                 scopes = [scopes]
             args["scopes"] = ",".join(scopes)
+        if provider and provider in [
+            "icloud",
+            "gmail",
+            "office365",
+            "exchange",
+            "imap",
+        ]:
+            args["provider"] = provider
+        if redirect_on_error is not None and isinstance(redirect_on_error, bool):
+            args["redirect_on_error"] = "true" if redirect_on_error is True else "false"
 
         url = URLObject(self.authorize_url).add_query_params(args.items())
         return str(url)
@@ -270,7 +292,7 @@ class APIClient(json.JSONEncoder):
         _validate(resp).json()
         return resp.json()
 
-    def free_busy(self, emails, start_at, end_at):
+    def free_busy(self, emails, start_at, end_at, calendars=None):
         if isinstance(emails, six.string_types):
             emails = [emails]
         if isinstance(start_at, datetime):
@@ -287,6 +309,10 @@ class APIClient(json.JSONEncoder):
             "start_time": start_time,
             "end_time": end_time,
         }
+        if calendars is not None and len(calendars) > 0:
+            data["calendars"] = calendars
+
+        _validate_availability_query(data)
         resp = self._request(HttpMethod.POST, url, json=data, cls=Calendar)
         _validate(resp)
         return resp.json()
@@ -321,6 +347,7 @@ class APIClient(json.JSONEncoder):
         round_robin=None,
         free_busy=None,
         open_hours=None,
+        calendars=None,
     ):
         if isinstance(emails, six.string_types):
             emails = [emails]
@@ -359,7 +386,10 @@ class APIClient(json.JSONEncoder):
             data["round_robin"] = round_robin
         if event_collection_id is not None:
             data["event_collection_id"] = event_collection_id
+        if calendars is not None and len(calendars) > 0:
+            data["calendars"] = calendars
 
+        _validate_availability_query(data)
         resp = self._request(HttpMethod.POST, url, json=data, cls=Calendar)
         _validate(resp)
         return resp.json()
@@ -374,10 +404,11 @@ class APIClient(json.JSONEncoder):
         buffer=None,
         free_busy=None,
         open_hours=None,
+        calendars=None,
     ):
         if isinstance(emails, six.string_types):
             emails = [[emails]]
-        elif isinstance(emails[0], list) is False:
+        elif len(emails) > 0 and isinstance(emails[0], list) is False:
             raise ValueError("'emails' must be a list of lists.")
         if isinstance(duration, timedelta):
             duration_minutes = int(duration.total_seconds() // 60)
@@ -412,7 +443,10 @@ class APIClient(json.JSONEncoder):
         }
         if buffer is not None:
             data["buffer"] = buffer
+        if calendars is not None and len(calendars) > 0:
+            data["calendars"] = calendars
 
+        _validate_availability_query(data)
         resp = self._request(HttpMethod.POST, url, json=data, cls=Calendar)
         _validate(resp)
         return resp.json()
@@ -607,6 +641,11 @@ class APIClient(json.JSONEncoder):
 
         if cls == File:
             response = self._request(HttpMethod.POST, url, cls=cls, files=data)
+        elif cls == Send and type(data) is not dict:
+            headers = {"Content-Type": "message/rfc822"}
+            response = self._request(
+                HttpMethod.POST, url, cls=cls, headers=headers, data=data
+            )
         else:
             converted_data = create_request_body(data, cls.datetime_attrs)
             headers = {"Content-Type": "application/json"}
@@ -786,19 +825,19 @@ class APIClient(json.JSONEncoder):
 
     def _add_auth_header(self, auth_method):
         authorization = None
-        if auth_method is AuthMethod.BEARER:
+        if auth_method == AuthMethod.BEARER:
             authorization = (
                 "Bearer {token}".format(token=self.access_token)
                 if self.access_token
                 else None
             )
-        elif auth_method is AuthMethod.BASIC_CLIENT_ID_AND_SECRET:
+        elif auth_method == AuthMethod.BASIC_CLIENT_ID_AND_SECRET:
             if self.client_id and self.client_secret:
                 credential = "{client_id}:{client_secret}".format(
                     client_id=self.client_id, client_secret=self.client_secret
                 )
                 authorization = "Basic {credential}".format(
-                    credential=b64encode(credential.encode("utf8"))
+                    credential=b64encode(credential.encode("utf8")).decode("utf8")
                 )
         else:
             if self.client_secret:
