@@ -514,6 +514,18 @@ class Draft(Message):
         if file.id in self.file_ids:
             self.file_ids.remove(file.id)
 
+    def send_raw(self, mime_message):
+        """
+        Send a raw MIME message
+
+        Args:
+            mime_message (str): The raw MIME message to send
+
+        Returns:
+            Message: The sent message
+        """
+        return self.api._create_resource(Send, mime_message)
+
     def send(self):
         if not self.id:
             data = self.as_json()
@@ -630,6 +642,7 @@ class Calendar(NylasAPIObject):
         "account_id",
         "name",
         "description",
+        "hex_color",
         "job_status_id",
         "metadata",
         "read_only",
@@ -640,7 +653,7 @@ class Calendar(NylasAPIObject):
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, Calendar, api)
-        self.read_only_attrs.update({"is_primary", "read_only"})
+        self.read_only_attrs.update({"is_primary", "read_only", "hex_color"})
 
     @property
     def events(self):
@@ -674,6 +687,7 @@ class Event(NylasAPIObject):
         "event_collection_id",
         "capacity",
         "round_robin_order",
+        "visibility",
     ]
     datetime_attrs = {"original_start_at": "original_start_time"}
     collection_name = "events"
@@ -829,6 +843,7 @@ class JobStatus(NylasAPIObject):
         "object",
         "status",
         "original_data",
+        "metadata",
     ]
     datetime_attrs = {"created_at": "created_at"}
     collection_name = "job-statuses"
