@@ -6,6 +6,7 @@ from urlobject import URLObject
 import responses
 from nylas.client import APIClient
 from nylas.client.restful_models import Contact
+from nylas.utils import AuthMethod
 
 
 def urls_equal(url1, url2):
@@ -143,6 +144,62 @@ def test_client_authentication_url_scopes_none(api_client, api_url):
     assert urls_equal(expected, actual)
 
 
+def test_client_authentication_url_optional_params(api_client, api_url):
+    expected = (
+        URLObject(api_url)
+        .with_path("/oauth/authorize")
+        .set_query_params(
+            [
+                ("login_hint", ""),
+                ("state", ""),
+                ("redirect_uri", "/redirect"),
+                ("response_type", "code"),
+                ("client_id", "None"),
+                ("scopes", "email"),
+                ("provider", "gmail"),
+                ("redirect_on_error", "false"),
+            ]
+        )
+    )
+    actual = URLObject(
+        api_client.authentication_url(
+            "/redirect", scopes="email", provider="gmail", redirect_on_error=False
+        )
+    )
+    assert urls_equal(expected, actual)
+
+
+def test_client_authentication_url_invalid_param_values(api_client, api_url):
+    expected = (
+        URLObject(api_url)
+        .with_path("/oauth/authorize")
+        .set_query_params(
+            [
+                ("login_hint", ""),
+                ("state", ""),
+                ("redirect_uri", "/redirect"),
+                ("response_type", "code"),
+                ("client_id", "None"),
+                ("scopes", "email"),
+            ]
+        )
+    )
+    actual = URLObject(
+        api_client.authentication_url("/redirect", scopes="email", provider="Google")
+    )
+    assert urls_equal(expected, actual)
+
+    expected2 = expected.set_query_param("provider", "gmail")
+
+    actual2 = URLObject(
+        api_client.authentication_url(
+            "/redirect", scopes="email", provider="gmail", redirect_on_error="true"
+        )
+    )
+
+    assert urls_equal(expected2, actual2)
+
+
 def test_client_token_for_code(mocked_responses, api_client, api_url):
     endpoint = re.compile(api_url + "/oauth/token")
     response_body = json.dumps({"access_token": "hooray"})
@@ -289,3 +346,22 @@ def test_count(mocked_responses, api_client, api_url):
 
     contact_count = api_client.contacts.count()
     assert contact_count == 721
+
+
+def test_add_auth_header_bearer(api_client):
+    api_client.access_token = "access_token"
+    auth_header = api_client._add_auth_header(AuthMethod.BEARER)
+    assert auth_header == {"Authorization": "Bearer access_token"}
+
+
+def test_add_auth_header_basic_client_id_and_secret(api_client):
+    api_client.client_id = "client_id"
+    api_client.client_secret = "client_secret"
+    auth_header = api_client._add_auth_header(AuthMethod.BASIC_CLIENT_ID_AND_SECRET)
+    assert auth_header == {"Authorization": "Basic Y2xpZW50X2lkOmNsaWVudF9zZWNyZXQ="}
+
+
+def test_add_auth_header_basic(api_client):
+    api_client.client_secret = "client_secret"
+    auth_header = api_client._add_auth_header(AuthMethod.BASIC)
+    assert auth_header == {"Authorization": "Basic Y2xpZW50X3NlY3JldDo="}
